@@ -23,7 +23,7 @@ class TestMainWindow : public KParts::MainWindow
     Q_OBJECT
 public:
     TestMainWindow();
-    virtual ~TestMainWindow();
+    ~TestMainWindow() override;
 
 protected Q_SLOTS:
     void slotFileOpen();
@@ -35,7 +35,6 @@ protected:
     void embedEditor();
 
 private:
-
     QAction *m_paEditFile;
     QAction *m_paCloseEditor;
 
